# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class Organization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avatar_url': 'str',
        'description': 'str',
        'full_name': 'str',
        'id': 'int',
        'location': 'str',
        'repo_admin_change_team_access': 'bool',
        'repo_languages': 'list[str]',
        'repo_subjects': 'list[str]',
        'username': 'str',
        'visibility': 'str',
        'website': 'str'
    }

    attribute_map = {
        'avatar_url': 'avatar_url',
        'description': 'description',
        'full_name': 'full_name',
        'id': 'id',
        'location': 'location',
        'repo_admin_change_team_access': 'repo_admin_change_team_access',
        'repo_languages': 'repo_languages',
        'repo_subjects': 'repo_subjects',
        'username': 'username',
        'visibility': 'visibility',
        'website': 'website'
    }

    def __init__(self, avatar_url=None, description=None, full_name=None, id=None, location=None, repo_admin_change_team_access=None, repo_languages=None, repo_subjects=None, username=None, visibility=None, website=None, _configuration=None):  # noqa: E501
        """Organization - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._avatar_url = None
        self._description = None
        self._full_name = None
        self._id = None
        self._location = None
        self._repo_admin_change_team_access = None
        self._repo_languages = None
        self._repo_subjects = None
        self._username = None
        self._visibility = None
        self._website = None
        self.discriminator = None

        if avatar_url is not None:
            self.avatar_url = avatar_url
        if description is not None:
            self.description = description
        if full_name is not None:
            self.full_name = full_name
        if id is not None:
            self.id = id
        if location is not None:
            self.location = location
        if repo_admin_change_team_access is not None:
            self.repo_admin_change_team_access = repo_admin_change_team_access
        if repo_languages is not None:
            self.repo_languages = repo_languages
        if repo_subjects is not None:
            self.repo_subjects = repo_subjects
        if username is not None:
            self.username = username
        if visibility is not None:
            self.visibility = visibility
        if website is not None:
            self.website = website

    @property
    def avatar_url(self):
        """Gets the avatar_url of this Organization.  # noqa: E501


        :return: The avatar_url of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this Organization.


        :param avatar_url: The avatar_url of this Organization.  # noqa: E501
        :type: str
        """

        self._avatar_url = avatar_url

    @property
    def description(self):
        """Gets the description of this Organization.  # noqa: E501


        :return: The description of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Organization.


        :param description: The description of this Organization.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def full_name(self):
        """Gets the full_name of this Organization.  # noqa: E501


        :return: The full_name of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this Organization.


        :param full_name: The full_name of this Organization.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def id(self):
        """Gets the id of this Organization.  # noqa: E501


        :return: The id of this Organization.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Organization.


        :param id: The id of this Organization.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def location(self):
        """Gets the location of this Organization.  # noqa: E501


        :return: The location of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Organization.


        :param location: The location of this Organization.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def repo_admin_change_team_access(self):
        """Gets the repo_admin_change_team_access of this Organization.  # noqa: E501


        :return: The repo_admin_change_team_access of this Organization.  # noqa: E501
        :rtype: bool
        """
        return self._repo_admin_change_team_access

    @repo_admin_change_team_access.setter
    def repo_admin_change_team_access(self, repo_admin_change_team_access):
        """Sets the repo_admin_change_team_access of this Organization.


        :param repo_admin_change_team_access: The repo_admin_change_team_access of this Organization.  # noqa: E501
        :type: bool
        """

        self._repo_admin_change_team_access = repo_admin_change_team_access

    @property
    def repo_languages(self):
        """Gets the repo_languages of this Organization.  # noqa: E501

        DCS Customizations ***/  # noqa: E501

        :return: The repo_languages of this Organization.  # noqa: E501
        :rtype: list[str]
        """
        return self._repo_languages

    @repo_languages.setter
    def repo_languages(self, repo_languages):
        """Sets the repo_languages of this Organization.

        DCS Customizations ***/  # noqa: E501

        :param repo_languages: The repo_languages of this Organization.  # noqa: E501
        :type: list[str]
        """

        self._repo_languages = repo_languages

    @property
    def repo_subjects(self):
        """Gets the repo_subjects of this Organization.  # noqa: E501


        :return: The repo_subjects of this Organization.  # noqa: E501
        :rtype: list[str]
        """
        return self._repo_subjects

    @repo_subjects.setter
    def repo_subjects(self, repo_subjects):
        """Sets the repo_subjects of this Organization.


        :param repo_subjects: The repo_subjects of this Organization.  # noqa: E501
        :type: list[str]
        """

        self._repo_subjects = repo_subjects

    @property
    def username(self):
        """Gets the username of this Organization.  # noqa: E501


        :return: The username of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this Organization.


        :param username: The username of this Organization.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def visibility(self):
        """Gets the visibility of this Organization.  # noqa: E501


        :return: The visibility of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this Organization.


        :param visibility: The visibility of this Organization.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def website(self):
        """Gets the website of this Organization.  # noqa: E501


        :return: The website of this Organization.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this Organization.


        :param website: The website of this Organization.  # noqa: E501
        :type: str
        """

        self._website = website

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Organization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Organization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Organization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active': 'bool',
        'avatar_url': 'str',
        'created': 'datetime',
        'description': 'str',
        'email': 'str',
        'followers_count': 'int',
        'following_count': 'int',
        'full_name': 'str',
        'id': 'int',
        'is_admin': 'bool',
        'language': 'str',
        'last_login': 'datetime',
        'location': 'str',
        'login': 'str',
        'prohibit_login': 'bool',
        'repo_languages': 'list[str]',
        'repo_subjects': 'list[str]',
        'restricted': 'bool',
        'starred_repos_count': 'int',
        'visibility': 'str',
        'website': 'str'
    }

    attribute_map = {
        'active': 'active',
        'avatar_url': 'avatar_url',
        'created': 'created',
        'description': 'description',
        'email': 'email',
        'followers_count': 'followers_count',
        'following_count': 'following_count',
        'full_name': 'full_name',
        'id': 'id',
        'is_admin': 'is_admin',
        'language': 'language',
        'last_login': 'last_login',
        'location': 'location',
        'login': 'login',
        'prohibit_login': 'prohibit_login',
        'repo_languages': 'repo_languages',
        'repo_subjects': 'repo_subjects',
        'restricted': 'restricted',
        'starred_repos_count': 'starred_repos_count',
        'visibility': 'visibility',
        'website': 'website'
    }

    def __init__(self, active=None, avatar_url=None, created=None, description=None, email=None, followers_count=None, following_count=None, full_name=None, id=None, is_admin=None, language=None, last_login=None, location=None, login=None, prohibit_login=None, repo_languages=None, repo_subjects=None, restricted=None, starred_repos_count=None, visibility=None, website=None, _configuration=None):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active = None
        self._avatar_url = None
        self._created = None
        self._description = None
        self._email = None
        self._followers_count = None
        self._following_count = None
        self._full_name = None
        self._id = None
        self._is_admin = None
        self._language = None
        self._last_login = None
        self._location = None
        self._login = None
        self._prohibit_login = None
        self._repo_languages = None
        self._repo_subjects = None
        self._restricted = None
        self._starred_repos_count = None
        self._visibility = None
        self._website = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if avatar_url is not None:
            self.avatar_url = avatar_url
        if created is not None:
            self.created = created
        if description is not None:
            self.description = description
        if email is not None:
            self.email = email
        if followers_count is not None:
            self.followers_count = followers_count
        if following_count is not None:
            self.following_count = following_count
        if full_name is not None:
            self.full_name = full_name
        if id is not None:
            self.id = id
        if is_admin is not None:
            self.is_admin = is_admin
        if language is not None:
            self.language = language
        if last_login is not None:
            self.last_login = last_login
        if location is not None:
            self.location = location
        if login is not None:
            self.login = login
        if prohibit_login is not None:
            self.prohibit_login = prohibit_login
        if repo_languages is not None:
            self.repo_languages = repo_languages
        if repo_subjects is not None:
            self.repo_subjects = repo_subjects
        if restricted is not None:
            self.restricted = restricted
        if starred_repos_count is not None:
            self.starred_repos_count = starred_repos_count
        if visibility is not None:
            self.visibility = visibility
        if website is not None:
            self.website = website

    @property
    def active(self):
        """Gets the active of this User.  # noqa: E501

        Is user active  # noqa: E501

        :return: The active of this User.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this User.

        Is user active  # noqa: E501

        :param active: The active of this User.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def avatar_url(self):
        """Gets the avatar_url of this User.  # noqa: E501

        URL to the user's avatar  # noqa: E501

        :return: The avatar_url of this User.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this User.

        URL to the user's avatar  # noqa: E501

        :param avatar_url: The avatar_url of this User.  # noqa: E501
        :type: str
        """

        self._avatar_url = avatar_url

    @property
    def created(self):
        """Gets the created of this User.  # noqa: E501


        :return: The created of this User.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this User.


        :param created: The created of this User.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def description(self):
        """Gets the description of this User.  # noqa: E501

        the user's description  # noqa: E501

        :return: The description of this User.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this User.

        the user's description  # noqa: E501

        :param description: The description of this User.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def email(self):
        """Gets the email of this User.  # noqa: E501


        :return: The email of this User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this User.


        :param email: The email of this User.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def followers_count(self):
        """Gets the followers_count of this User.  # noqa: E501

        user counts  # noqa: E501

        :return: The followers_count of this User.  # noqa: E501
        :rtype: int
        """
        return self._followers_count

    @followers_count.setter
    def followers_count(self, followers_count):
        """Sets the followers_count of this User.

        user counts  # noqa: E501

        :param followers_count: The followers_count of this User.  # noqa: E501
        :type: int
        """

        self._followers_count = followers_count

    @property
    def following_count(self):
        """Gets the following_count of this User.  # noqa: E501


        :return: The following_count of this User.  # noqa: E501
        :rtype: int
        """
        return self._following_count

    @following_count.setter
    def following_count(self, following_count):
        """Sets the following_count of this User.


        :param following_count: The following_count of this User.  # noqa: E501
        :type: int
        """

        self._following_count = following_count

    @property
    def full_name(self):
        """Gets the full_name of this User.  # noqa: E501

        the user's full name  # noqa: E501

        :return: The full_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this User.

        the user's full name  # noqa: E501

        :param full_name: The full_name of this User.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501

        the user's id  # noqa: E501

        :return: The id of this User.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.

        the user's id  # noqa: E501

        :param id: The id of this User.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def is_admin(self):
        """Gets the is_admin of this User.  # noqa: E501

        Is the user an administrator  # noqa: E501

        :return: The is_admin of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this User.

        Is the user an administrator  # noqa: E501

        :param is_admin: The is_admin of this User.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def language(self):
        """Gets the language of this User.  # noqa: E501

        User locale  # noqa: E501

        :return: The language of this User.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this User.

        User locale  # noqa: E501

        :param language: The language of this User.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def last_login(self):
        """Gets the last_login of this User.  # noqa: E501


        :return: The last_login of this User.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login

    @last_login.setter
    def last_login(self, last_login):
        """Sets the last_login of this User.


        :param last_login: The last_login of this User.  # noqa: E501
        :type: datetime
        """

        self._last_login = last_login

    @property
    def location(self):
        """Gets the location of this User.  # noqa: E501

        the user's location  # noqa: E501

        :return: The location of this User.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this User.

        the user's location  # noqa: E501

        :param location: The location of this User.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def login(self):
        """Gets the login of this User.  # noqa: E501

        the user's username  # noqa: E501

        :return: The login of this User.  # noqa: E501
        :rtype: str
        """
        return self._login

    @login.setter
    def login(self, login):
        """Sets the login of this User.

        the user's username  # noqa: E501

        :param login: The login of this User.  # noqa: E501
        :type: str
        """

        self._login = login

    @property
    def prohibit_login(self):
        """Gets the prohibit_login of this User.  # noqa: E501

        Is user login prohibited  # noqa: E501

        :return: The prohibit_login of this User.  # noqa: E501
        :rtype: bool
        """
        return self._prohibit_login

    @prohibit_login.setter
    def prohibit_login(self, prohibit_login):
        """Sets the prohibit_login of this User.

        Is user login prohibited  # noqa: E501

        :param prohibit_login: The prohibit_login of this User.  # noqa: E501
        :type: bool
        """

        self._prohibit_login = prohibit_login

    @property
    def repo_languages(self):
        """Gets the repo_languages of this User.  # noqa: E501

        DCS Customizations ***/ Repo languages  # noqa: E501

        :return: The repo_languages of this User.  # noqa: E501
        :rtype: list[str]
        """
        return self._repo_languages

    @repo_languages.setter
    def repo_languages(self, repo_languages):
        """Sets the repo_languages of this User.

        DCS Customizations ***/ Repo languages  # noqa: E501

        :param repo_languages: The repo_languages of this User.  # noqa: E501
        :type: list[str]
        """

        self._repo_languages = repo_languages

    @property
    def repo_subjects(self):
        """Gets the repo_subjects of this User.  # noqa: E501

        Repo subjects  # noqa: E501

        :return: The repo_subjects of this User.  # noqa: E501
        :rtype: list[str]
        """
        return self._repo_subjects

    @repo_subjects.setter
    def repo_subjects(self, repo_subjects):
        """Sets the repo_subjects of this User.

        Repo subjects  # noqa: E501

        :param repo_subjects: The repo_subjects of this User.  # noqa: E501
        :type: list[str]
        """

        self._repo_subjects = repo_subjects

    @property
    def restricted(self):
        """Gets the restricted of this User.  # noqa: E501

        END DCS Customizations ***/ Is user restricted  # noqa: E501

        :return: The restricted of this User.  # noqa: E501
        :rtype: bool
        """
        return self._restricted

    @restricted.setter
    def restricted(self, restricted):
        """Sets the restricted of this User.

        END DCS Customizations ***/ Is user restricted  # noqa: E501

        :param restricted: The restricted of this User.  # noqa: E501
        :type: bool
        """

        self._restricted = restricted

    @property
    def starred_repos_count(self):
        """Gets the starred_repos_count of this User.  # noqa: E501


        :return: The starred_repos_count of this User.  # noqa: E501
        :rtype: int
        """
        return self._starred_repos_count

    @starred_repos_count.setter
    def starred_repos_count(self, starred_repos_count):
        """Sets the starred_repos_count of this User.


        :param starred_repos_count: The starred_repos_count of this User.  # noqa: E501
        :type: int
        """

        self._starred_repos_count = starred_repos_count

    @property
    def visibility(self):
        """Gets the visibility of this User.  # noqa: E501

        User visibility level option: public, limited, private  # noqa: E501

        :return: The visibility of this User.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this User.

        User visibility level option: public, limited, private  # noqa: E501

        :param visibility: The visibility of this User.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def website(self):
        """Gets the website of this User.  # noqa: E501

        the user's website  # noqa: E501

        :return: The website of this User.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this User.

        the user's website  # noqa: E501

        :param website: The website of this User.  # noqa: E501
        :type: str
        """

        self._website = website

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, User):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class OAuth2Application(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'client_id': 'str',
        'client_secret': 'str',
        'created': 'datetime',
        'id': 'int',
        'name': 'str',
        'redirect_uris': 'list[str]'
    }

    attribute_map = {
        'client_id': 'client_id',
        'client_secret': 'client_secret',
        'created': 'created',
        'id': 'id',
        'name': 'name',
        'redirect_uris': 'redirect_uris'
    }

    def __init__(self, client_id=None, client_secret=None, created=None, id=None, name=None, redirect_uris=None, _configuration=None):  # noqa: E501
        """OAuth2Application - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._client_id = None
        self._client_secret = None
        self._created = None
        self._id = None
        self._name = None
        self._redirect_uris = None
        self.discriminator = None

        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if created is not None:
            self.created = created
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if redirect_uris is not None:
            self.redirect_uris = redirect_uris

    @property
    def client_id(self):
        """Gets the client_id of this OAuth2Application.  # noqa: E501


        :return: The client_id of this OAuth2Application.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this OAuth2Application.


        :param client_id: The client_id of this OAuth2Application.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this OAuth2Application.  # noqa: E501


        :return: The client_secret of this OAuth2Application.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this OAuth2Application.


        :param client_secret: The client_secret of this OAuth2Application.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def created(self):
        """Gets the created of this OAuth2Application.  # noqa: E501


        :return: The created of this OAuth2Application.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this OAuth2Application.


        :param created: The created of this OAuth2Application.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def id(self):
        """Gets the id of this OAuth2Application.  # noqa: E501


        :return: The id of this OAuth2Application.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OAuth2Application.


        :param id: The id of this OAuth2Application.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OAuth2Application.  # noqa: E501


        :return: The name of this OAuth2Application.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OAuth2Application.


        :param name: The name of this OAuth2Application.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def redirect_uris(self):
        """Gets the redirect_uris of this OAuth2Application.  # noqa: E501


        :return: The redirect_uris of this OAuth2Application.  # noqa: E501
        :rtype: list[str]
        """
        return self._redirect_uris

    @redirect_uris.setter
    def redirect_uris(self, redirect_uris):
        """Sets the redirect_uris of this OAuth2Application.


        :param redirect_uris: The redirect_uris of this OAuth2Application.  # noqa: E501
        :type: list[str]
        """

        self._redirect_uris = redirect_uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OAuth2Application, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuth2Application):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OAuth2Application):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class Attachment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'browser_download_url': 'str',
        'created_at': 'datetime',
        'download_count': 'int',
        'id': 'int',
        'name': 'str',
        'size': 'int',
        'uuid': 'str'
    }

    attribute_map = {
        'browser_download_url': 'browser_download_url',
        'created_at': 'created_at',
        'download_count': 'download_count',
        'id': 'id',
        'name': 'name',
        'size': 'size',
        'uuid': 'uuid'
    }

    def __init__(self, browser_download_url=None, created_at=None, download_count=None, id=None, name=None, size=None, uuid=None, _configuration=None):  # noqa: E501
        """Attachment - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._browser_download_url = None
        self._created_at = None
        self._download_count = None
        self._id = None
        self._name = None
        self._size = None
        self._uuid = None
        self.discriminator = None

        if browser_download_url is not None:
            self.browser_download_url = browser_download_url
        if created_at is not None:
            self.created_at = created_at
        if download_count is not None:
            self.download_count = download_count
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if size is not None:
            self.size = size
        if uuid is not None:
            self.uuid = uuid

    @property
    def browser_download_url(self):
        """Gets the browser_download_url of this Attachment.  # noqa: E501


        :return: The browser_download_url of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._browser_download_url

    @browser_download_url.setter
    def browser_download_url(self, browser_download_url):
        """Sets the browser_download_url of this Attachment.


        :param browser_download_url: The browser_download_url of this Attachment.  # noqa: E501
        :type: str
        """

        self._browser_download_url = browser_download_url

    @property
    def created_at(self):
        """Gets the created_at of this Attachment.  # noqa: E501


        :return: The created_at of this Attachment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Attachment.


        :param created_at: The created_at of this Attachment.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def download_count(self):
        """Gets the download_count of this Attachment.  # noqa: E501


        :return: The download_count of this Attachment.  # noqa: E501
        :rtype: int
        """
        return self._download_count

    @download_count.setter
    def download_count(self, download_count):
        """Sets the download_count of this Attachment.


        :param download_count: The download_count of this Attachment.  # noqa: E501
        :type: int
        """

        self._download_count = download_count

    @property
    def id(self):
        """Gets the id of this Attachment.  # noqa: E501


        :return: The id of this Attachment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Attachment.


        :param id: The id of this Attachment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Attachment.  # noqa: E501


        :return: The name of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Attachment.


        :param name: The name of this Attachment.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def size(self):
        """Gets the size of this Attachment.  # noqa: E501


        :return: The size of this Attachment.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Attachment.


        :param size: The size of this Attachment.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def uuid(self):
        """Gets the uuid of this Attachment.  # noqa: E501


        :return: The uuid of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this Attachment.


        :param uuid: The uuid of this Attachment.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Attachment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Attachment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Attachment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class Team(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'can_create_org_repo': 'bool',
        'description': 'str',
        'id': 'int',
        'includes_all_repositories': 'bool',
        'name': 'str',
        'organization': 'Organization',
        'permission': 'str',
        'units': 'list[str]',
        'units_map': 'dict(str, str)'
    }

    attribute_map = {
        'can_create_org_repo': 'can_create_org_repo',
        'description': 'description',
        'id': 'id',
        'includes_all_repositories': 'includes_all_repositories',
        'name': 'name',
        'organization': 'organization',
        'permission': 'permission',
        'units': 'units',
        'units_map': 'units_map'
    }

    def __init__(self, can_create_org_repo=None, description=None, id=None, includes_all_repositories=None, name=None, organization=None, permission=None, units=None, units_map=None, _configuration=None):  # noqa: E501
        """Team - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._can_create_org_repo = None
        self._description = None
        self._id = None
        self._includes_all_repositories = None
        self._name = None
        self._organization = None
        self._permission = None
        self._units = None
        self._units_map = None
        self.discriminator = None

        if can_create_org_repo is not None:
            self.can_create_org_repo = can_create_org_repo
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if includes_all_repositories is not None:
            self.includes_all_repositories = includes_all_repositories
        if name is not None:
            self.name = name
        if organization is not None:
            self.organization = organization
        if permission is not None:
            self.permission = permission
        if units is not None:
            self.units = units
        if units_map is not None:
            self.units_map = units_map

    @property
    def can_create_org_repo(self):
        """Gets the can_create_org_repo of this Team.  # noqa: E501


        :return: The can_create_org_repo of this Team.  # noqa: E501
        :rtype: bool
        """
        return self._can_create_org_repo

    @can_create_org_repo.setter
    def can_create_org_repo(self, can_create_org_repo):
        """Sets the can_create_org_repo of this Team.


        :param can_create_org_repo: The can_create_org_repo of this Team.  # noqa: E501
        :type: bool
        """

        self._can_create_org_repo = can_create_org_repo

    @property
    def description(self):
        """Gets the description of this Team.  # noqa: E501


        :return: The description of this Team.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Team.


        :param description: The description of this Team.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this Team.  # noqa: E501


        :return: The id of this Team.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Team.


        :param id: The id of this Team.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def includes_all_repositories(self):
        """Gets the includes_all_repositories of this Team.  # noqa: E501


        :return: The includes_all_repositories of this Team.  # noqa: E501
        :rtype: bool
        """
        return self._includes_all_repositories

    @includes_all_repositories.setter
    def includes_all_repositories(self, includes_all_repositories):
        """Sets the includes_all_repositories of this Team.


        :param includes_all_repositories: The includes_all_repositories of this Team.  # noqa: E501
        :type: bool
        """

        self._includes_all_repositories = includes_all_repositories

    @property
    def name(self):
        """Gets the name of this Team.  # noqa: E501


        :return: The name of this Team.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Team.


        :param name: The name of this Team.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def organization(self):
        """Gets the organization of this Team.  # noqa: E501


        :return: The organization of this Team.  # noqa: E501
        :rtype: Organization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this Team.


        :param organization: The organization of this Team.  # noqa: E501
        :type: Organization
        """

        self._organization = organization

    @property
    def permission(self):
        """Gets the permission of this Team.  # noqa: E501


        :return: The permission of this Team.  # noqa: E501
        :rtype: str
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this Team.


        :param permission: The permission of this Team.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "read", "write", "admin", "owner"]  # noqa: E501
        if (self._configuration.client_side_validation and
                permission not in allowed_values):
            raise ValueError(
                "Invalid value for `permission` ({0}), must be one of {1}"  # noqa: E501
                .format(permission, allowed_values)
            )

        self._permission = permission

    @property
    def units(self):
        """Gets the units of this Team.  # noqa: E501


        :return: The units of this Team.  # noqa: E501
        :rtype: list[str]
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this Team.


        :param units: The units of this Team.  # noqa: E501
        :type: list[str]
        """

        self._units = units

    @property
    def units_map(self):
        """Gets the units_map of this Team.  # noqa: E501


        :return: The units_map of this Team.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._units_map

    @units_map.setter
    def units_map(self, units_map):
        """Sets the units_map of this Team.


        :param units_map: The units_map of this Team.  # noqa: E501
        :type: dict(str, str)
        """

        self._units_map = units_map

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Team, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Team):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Team):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import dcs_catalog_client
from dcs_catalog_client.api.v3_api import V3Api  # noqa: E501
from dcs_catalog_client.rest import ApiException


class TestV3Api(unittest.TestCase):
    """V3Api unit test stubs"""

    def setUp(self):
        self.api = dcs_catalog_client.api.v3_api.V3Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_catalog_search_v3(self):
        """Test case for catalog_search_v3

        Catalog v3 search  # noqa: E501
        """
        pass

    def test_catalog_subjects_pivoted_by_subject_v3(self):
        """Test case for catalog_subjects_pivoted_by_subject_v3

        Catalog v3 listing pivoted on subject by a given subject (e.g. /v3/subjects/Open_Bible_Stories.json)  # noqa: E501
        """
        pass

    def test_catalog_subjects_pivoted_search_v3(self):
        """Test case for catalog_subjects_pivoted_search_v3

        Catalog v3 search pivoted by subject/language  # noqa: E501
        """
        pass

    def test_catalog_subjects_pivoted_v3(self):
        """Test case for catalog_subjects_pivoted_v3

        Catalog v3 listing pivoted by subject/language, back-port of https://api.door43.org/v3/subjects/pivoted.json  # noqa: E501
        """
        pass

    def test_catalog_v3(self):
        """Test case for catalog_v3

        Catalog v3 listing by language, back-port of https://api.door43.org/v3/catalog.json  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class CatalogSearchResultsPivotedV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'list[CatalogV3Pivoted]',
        'last_updated': 'datetime',
        'ok': 'bool'
    }

    attribute_map = {
        'data': 'data',
        'last_updated': 'last_updated',
        'ok': 'ok'
    }

    def __init__(self, data=None, last_updated=None, ok=None, _configuration=None):  # noqa: E501
        """CatalogSearchResultsPivotedV3 - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._data = None
        self._last_updated = None
        self._ok = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if last_updated is not None:
            self.last_updated = last_updated
        if ok is not None:
            self.ok = ok

    @property
    def data(self):
        """Gets the data of this CatalogSearchResultsPivotedV3.  # noqa: E501


        :return: The data of this CatalogSearchResultsPivotedV3.  # noqa: E501
        :rtype: list[CatalogV3Pivoted]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this CatalogSearchResultsPivotedV3.


        :param data: The data of this CatalogSearchResultsPivotedV3.  # noqa: E501
        :type: list[CatalogV3Pivoted]
        """

        self._data = data

    @property
    def last_updated(self):
        """Gets the last_updated of this CatalogSearchResultsPivotedV3.  # noqa: E501


        :return: The last_updated of this CatalogSearchResultsPivotedV3.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this CatalogSearchResultsPivotedV3.


        :param last_updated: The last_updated of this CatalogSearchResultsPivotedV3.  # noqa: E501
        :type: datetime
        """

        self._last_updated = last_updated

    @property
    def ok(self):
        """Gets the ok of this CatalogSearchResultsPivotedV3.  # noqa: E501


        :return: The ok of this CatalogSearchResultsPivotedV3.  # noqa: E501
        :rtype: bool
        """
        return self._ok

    @ok.setter
    def ok(self, ok):
        """Sets the ok of this CatalogSearchResultsPivotedV3.


        :param ok: The ok of this CatalogSearchResultsPivotedV3.  # noqa: E501
        :type: bool
        """

        self._ok = ok

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CatalogSearchResultsPivotedV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogSearchResultsPivotedV3):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogSearchResultsPivotedV3):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dcs_catalog_client.api.misc_api import MiscApi
from dcs_catalog_client.api.v3_api import V3Api
from dcs_catalog_client.api.v4_api import V4Api
from dcs_catalog_client.api.v5_api import V5Api



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dcs_catalog_client.api_client import ApiClient


class V3Api(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def catalog_search_v3(self, **kwargs):  # noqa: E501
        """Catalog v3 search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_search_v3(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: search only for entries with the given owner name(s). Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str repo: search only for entries with the given repo name(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str lang: search only for entries with the given language(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive)
        :param str subject: search only for entries with the given subject(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param bool partial_match: if true, subject, owner and repo search fields will use partial match (LIKE) when querying the catalog. Default is false
        :return: CatalogSearchResultsV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_search_v3_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.catalog_search_v3_with_http_info(**kwargs)  # noqa: E501
            return data

    def catalog_search_v3_with_http_info(self, **kwargs):  # noqa: E501
        """Catalog v3 search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_search_v3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: search only for entries with the given owner name(s). Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str repo: search only for entries with the given repo name(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str lang: search only for entries with the given language(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive)
        :param str subject: search only for entries with the given subject(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param bool partial_match: if true, subject, owner and repo search fields will use partial match (LIKE) when querying the catalog. Default is false
        :return: CatalogSearchResultsV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner', 'repo', 'lang', 'subject', 'partial_match']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_search_v3" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'owner' in params:
            query_params.append(('owner', params['owner']))  # noqa: E501
        if 'repo' in params:
            query_params.append(('repo', params['repo']))  # noqa: E501
        if 'lang' in params:
            query_params.append(('lang', params['lang']))  # noqa: E501
        if 'subject' in params:
            query_params.append(('subject', params['subject']))  # noqa: E501
        if 'partial_match' in params:
            query_params.append(('partialMatch', params['partial_match']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v3/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_subjects_pivoted_by_subject_v3(self, subject, **kwargs):  # noqa: E501
        """Catalog v3 listing pivoted on subject by a given subject (e.g. /v3/subjects/Open_Bible_Stories.json)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_subjects_pivoted_by_subject_v3(subject, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subject: subject to query (required)
        :return: CatalogSearchResultsPivotedV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_subjects_pivoted_by_subject_v3_with_http_info(subject, **kwargs)  # noqa: E501
        else:
            (data) = self.catalog_subjects_pivoted_by_subject_v3_with_http_info(subject, **kwargs)  # noqa: E501
            return data

    def catalog_subjects_pivoted_by_subject_v3_with_http_info(self, subject, **kwargs):  # noqa: E501
        """Catalog v3 listing pivoted on subject by a given subject (e.g. /v3/subjects/Open_Bible_Stories.json)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_subjects_pivoted_by_subject_v3_with_http_info(subject, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subject: subject to query (required)
        :return: CatalogSearchResultsPivotedV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['subject']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_subjects_pivoted_by_subject_v3" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'subject' is set
        if self.api_client.client_side_validation and ('subject' not in params or
                                                       params['subject'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `subject` when calling `catalog_subjects_pivoted_by_subject_v3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subject' in params:
            path_params['subject'] = params['subject']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v3/subjects/{subject}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsPivotedV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_subjects_pivoted_search_v3(self, **kwargs):  # noqa: E501
        """Catalog v3 search pivoted by subject/language  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_subjects_pivoted_search_v3(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: search only for entries with the given owner name(s). Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str repo: search only for entries with the given repo name(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str lang: search only for entries with the given language(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive)
        :param str subject: search only for entries with the given subject(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param bool partial_match: if true, subject, owner and repo search fields will use partial match (LIKE) when querying the catalog. Default is false
        :return: CatalogSearchResultsPivotedV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_subjects_pivoted_search_v3_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.catalog_subjects_pivoted_search_v3_with_http_info(**kwargs)  # noqa: E501
            return data

    def catalog_subjects_pivoted_search_v3_with_http_info(self, **kwargs):  # noqa: E501
        """Catalog v3 search pivoted by subject/language  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_subjects_pivoted_search_v3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: search only for entries with the given owner name(s). Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str repo: search only for entries with the given repo name(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param str lang: search only for entries with the given language(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive)
        :param str subject: search only for entries with the given subject(s). To match multiple, give the parameter multiple times or give a list comma delimited. Will perform an exact match (case insensitive) unlesss partialMatch=true
        :param bool partial_match: if true, subject, owner and repo search fields will use partial match (LIKE) when querying the catalog. Default is false
        :return: CatalogSearchResultsPivotedV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner', 'repo', 'lang', 'subject', 'partial_match']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_subjects_pivoted_search_v3" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'owner' in params:
            query_params.append(('owner', params['owner']))  # noqa: E501
        if 'repo' in params:
            query_params.append(('repo', params['repo']))  # noqa: E501
        if 'lang' in params:
            query_params.append(('lang', params['lang']))  # noqa: E501
        if 'subject' in params:
            query_params.append(('subject', params['subject']))  # noqa: E501
        if 'partial_match' in params:
            query_params.append(('partialMatch', params['partial_match']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v3/subjects/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsPivotedV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_subjects_pivoted_v3(self, **kwargs):  # noqa: E501
        """Catalog v3 listing pivoted by subject/language, back-port of https://api.door43.org/v3/subjects/pivoted.json  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_subjects_pivoted_v3(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CatalogSearchResultsPivotedV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_subjects_pivoted_v3_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.catalog_subjects_pivoted_v3_with_http_info(**kwargs)  # noqa: E501
            return data

    def catalog_subjects_pivoted_v3_with_http_info(self, **kwargs):  # noqa: E501
        """Catalog v3 listing pivoted by subject/language, back-port of https://api.door43.org/v3/subjects/pivoted.json  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_subjects_pivoted_v3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CatalogSearchResultsPivotedV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_subjects_pivoted_v3" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v3/subjects/pivoted.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsPivotedV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_v3(self, **kwargs):  # noqa: E501
        """Catalog v3 listing by language, back-port of https://api.door43.org/v3/catalog.json  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_v3(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CatalogSearchResultsV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_v3_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.catalog_v3_with_http_info(**kwargs)  # noqa: E501
            return data

    def catalog_v3_with_http_info(self, **kwargs):  # noqa: E501
        """Catalog v3 listing by language, back-port of https://api.door43.org/v3/catalog.json  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_v3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CatalogSearchResultsV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_v3" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v3/catalog.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dcs_catalog_client.api_client import ApiClient


class V4Api(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def catalo4_search_owner(self, owner, **kwargs):  # noqa: E501
        """Catalog search by owner  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalo4_search_owner(owner, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: owner of entries (required)
        :param str q: keyword(s). Can use multiple `q=<keyword>`s or commas for more than one keyword
        :param str repo: search only for entries with the given repo name(s).
        :param str tag: search only for entries with the given release tag(s)
        :param str lang: search only for entries with the given language(s)
        :param str stage: specifies which release stage to be return of these stages: \"prod\" - return only the production releases (default); \"preprod\" - return the pre-production release if it exists instead of the production release; \"draft\" - return the draft release if it exists instead of pre-production or production release; \"latest\" -return the default branch (e.g. master) if it is a valid RC instead of the above
        :param str subject: search only for entries with the given subject(s). Must match the entire string (case insensitive)
        :param str checking_level: search only for entries with the given checking level(s). Can be 1, 2 or 3
        :param str book: search only for entries with the given book(s) (project ids)
        :param bool include_history: if true, all releases, not just the latest, are included. Default is false
        :param bool include_metadata: if false, only subject and title are searched with query terms, if true all metadata values are searched. Default is true
        :param bool show_ingredients: if true, a list of the projects in the resource and their file paths will be listed for each entry. Default is false
        :param str sort: sort repos alphanumerically by attribute. Supported values are \"subject\", \"title\", \"reponame\", \"tag\", \"released\", \"lang\", \"releases\", \"stars\", \"forks\". Default is by \"language\", \"subject\" and then \"tag\"
        :param str order: sort order, either \"asc\" (ascending) or \"desc\" (descending). Default is \"asc\", ignored if \"sort\" is not specified.
        :param int page: page number of results to return (1-based)
        :param int limit: page size of results, maximum page size is 50
        :return: CatalogSearchResultsV4
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalo4_search_owner_with_http_info(owner, **kwargs)  # noqa: E501
        else:
            (data) = self.catalo4_search_owner_with_http_info(owner, **kwargs)  # noqa: E501
            return data

    def catalo4_search_owner_with_http_info(self, owner, **kwargs):  # noqa: E501
        """Catalog search by owner  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalo4_search_owner_with_http_info(owner, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: owner of entries (required)
        :param str q: keyword(s). Can use multiple `q=<keyword>`s or commas for more than one keyword
        :param str repo: search only for entries with the given repo name(s).
        :param str tag: search only for entries with the given release tag(s)
        :param str lang: search only for entries with the given language(s)
        :param str stage: specifies which release stage to be return of these stages: \"prod\" - return only the production releases (default); \"preprod\" - return the pre-production release if it exists instead of the production release; \"draft\" - return the draft release if it exists instead of pre-production or production release; \"latest\" -return the default branch (e.g. master) if it is a valid RC instead of the above
        :param str subject: search only for entries with the given subject(s). Must match the entire string (case insensitive)
        :param str checking_level: search only for entries with the given checking level(s). Can be 1, 2 or 3
        :param str book: search only for entries with the given book(s) (project ids)
        :param bool include_history: if true, all releases, not just the latest, are included. Default is false
        :param bool include_metadata: if false, only subject and title are searched with query terms, if true all metadata values are searched. Default is true
        :param bool show_ingredients: if true, a list of the projects in the resource and their file paths will be listed for each entry. Default is false
        :param str sort: sort repos alphanumerically by attribute. Supported values are \"subject\", \"title\", \"reponame\", \"tag\", \"released\", \"lang\", \"releases\", \"stars\", \"forks\". Default is by \"language\", \"subject\" and then \"tag\"
        :param str order: sort order, either \"asc\" (ascending) or \"desc\" (descending). Default is \"asc\", ignored if \"sort\" is not specified.
        :param int page: page number of results to return (1-based)
        :param int limit: page size of results, maximum page size is 50
        :return: CatalogSearchResultsV4
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner', 'q', 'repo', 'tag', 'lang', 'stage', 'subject', 'checking_level', 'book', 'include_history', 'include_metadata', 'show_ingredients', 'sort', 'order', 'page', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalo4_search_owner" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'owner' is set
        if self.api_client.client_side_validation and ('owner' not in params or
                                                       params['owner'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `owner` when calling `catalo4_search_owner`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'owner' in params:
            path_params['owner'] = params['owner']  # noqa: E501

        query_params = []
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501
        if 'repo' in params:
            query_params.append(('repo', params['repo']))  # noqa: E501
        if 'tag' in params:
            query_params.append(('tag', params['tag']))  # noqa: E501
        if 'lang' in params:
            query_params.append(('lang', params['lang']))  # noqa: E501
        if 'stage' in params:
            query_params.append(('stage', params['stage']))  # noqa: E501
        if 'subject' in params:
            query_params.append(('subject', params['subject']))  # noqa: E501
        if 'checking_level' in params:
            query_params.append(('checkingLevel', params['checking_level']))  # noqa: E501
        if 'book' in params:
            query_params.append(('book', params['book']))  # noqa: E501
        if 'include_history' in params:
            query_params.append(('includeHistory', params['include_history']))  # noqa: E501
        if 'include_metadata' in params:
            query_params.append(('includeMetadata', params['include_metadata']))  # noqa: E501
        if 'show_ingredients' in params:
            query_params.append(('showIngredients', params['show_ingredients']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'order' in params:
            query_params.append(('order', params['order']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v4/search/{owner}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsV4',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_get_entry(self, owner, repo, tag, **kwargs):  # noqa: E501
        """Catalog entry  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_get_entry(owner, repo, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: name of the owner (required)
        :param str repo: name of the repo (required)
        :param str tag: release tag or default branch (required)
        :return: CatalogV4
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_get_entry_with_http_info(owner, repo, tag, **kwargs)  # noqa: E501
        else:
            (data) = self.catalog_get_entry_with_http_info(owner, repo, tag, **kwargs)  # noqa: E501
            return data

    def catalog_get_entry_with_http_info(self, owner, repo, tag, **kwargs):  # noqa: E501
        """Catalog entry  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_get_entry_with_http_info(owner, repo, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: name of the owner (required)
        :param str repo: name of the repo (required)
        :param str tag: release tag or default branch (required)
        :return: CatalogV4
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner', 'repo', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_get_entry" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'owner' is set
        if self.api_client.client_side_validation and ('owner' not in params or
                                                       params['owner'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `owner` when calling `catalog_get_entry`")  # noqa: E501
        # verify the required parameter 'repo' is set
        if self.api_client.client_side_validation and ('repo' not in params or
                                                       params['repo'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `repo` when calling `catalog_get_entry`")  # noqa: E501
        # verify the required parameter 'tag' is set
        if self.api_client.client_side_validation and ('tag' not in params or
                                                       params['tag'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag` when calling `catalog_get_entry`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'owner' in params:
            path_params['owner'] = params['owner']  # noqa: E501
        if 'repo' in params:
            path_params['repo'] = params['repo']  # noqa: E501
        if 'tag' in params:
            path_params['tag'] = params['tag']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v4/entry/{owner}/{repo}/{tag}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogV4',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_get_metadata(self, owner, repo, tag, **kwargs):  # noqa: E501
        """Catalog entry metadata (manifest.yaml in JSON format)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_get_metadata(owner, repo, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: name of the owner (required)
        :param str repo: name of the repo (required)
        :param str tag: release tag or default branch (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_get_metadata_with_http_info(owner, repo, tag, **kwargs)  # noqa: E501
        else:
            (data) = self.catalog_get_metadata_with_http_info(owner, repo, tag, **kwargs)  # noqa: E501
            return data

    def catalog_get_metadata_with_http_info(self, owner, repo, tag, **kwargs):  # noqa: E501
        """Catalog entry metadata (manifest.yaml in JSON format)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_get_metadata_with_http_info(owner, repo, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: name of the owner (required)
        :param str repo: name of the repo (required)
        :param str tag: release tag or default branch (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner', 'repo', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_get_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'owner' is set
        if self.api_client.client_side_validation and ('owner' not in params or
                                                       params['owner'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `owner` when calling `catalog_get_metadata`")  # noqa: E501
        # verify the required parameter 'repo' is set
        if self.api_client.client_side_validation and ('repo' not in params or
                                                       params['repo'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `repo` when calling `catalog_get_metadata`")  # noqa: E501
        # verify the required parameter 'tag' is set
        if self.api_client.client_side_validation and ('tag' not in params or
                                                       params['tag'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag` when calling `catalog_get_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'owner' in params:
            path_params['owner'] = params['owner']  # noqa: E501
        if 'repo' in params:
            path_params['repo'] = params['repo']  # noqa: E501
        if 'tag' in params:
            path_params['tag'] = params['tag']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v4/entry/{owner}/{repo}/{tag}/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_search(self, **kwargs):  # noqa: E501
        """Catalog search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_search(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str q: keyword(s). Can use multiple `q=<keyword>`s or commas for more than one keyword
        :param str owner: search only for entries with the given owner name(s).
        :param str repo: search only for entries with the given repo name(s).
        :param str tag: search only for entries with the given release tag(s)
        :param str lang: search only for entries with the given language(s)
        :param str stage: specifies which release stage to be return of these stages: \"prod\" - return only the production releases (default); \"preprod\" - return the pre-production release if it exists instead of the production release; \"draft\" - return the draft release if it exists instead of pre-production or production release; \"latest\" -return the default branch (e.g. master) if it is a valid RC instead of the above
        :param str subject: search only for entries with the given subject(s). Must match the entire string (case insensitive)
        :param str checking_level: search only for entries with the given checking level(s). Can be 1, 2 or 3
        :param str book: search only for entries with the given book(s) (project ids)
        :param bool include_history: if true, all releases, not just the latest, are included. Default is false
        :param bool include_metadata: if false, only subject and title are searched with query terms, if true all metadata values are searched. Default is true
        :param bool show_ingredients: if true, a list of the projects in the resource and their file paths will be listed for each entry. Default is false
        :param str sort: sort repos alphanumerically by attribute. Supported values are \"subject\", \"title\", \"reponame\", \"tag\", \"released\", \"lang\", \"releases\", \"stars\", \"forks\". Default is by \"language\", \"subject\" and then \"tag\"
        :param str order: sort order, either \"asc\" (ascending) or \"desc\" (descending). Default is \"asc\", ignored if \"sort\" is not specified.
        :param int page: page number of results to return (1-based)
        :param int limit: page size of results, maximum page size is 50
        :return: CatalogSearchResultsV4
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_search_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.catalog_search_with_http_info(**kwargs)  # noqa: E501
            return data

    def catalog_search_with_http_info(self, **kwargs):  # noqa: E501
        """Catalog search  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str q: keyword(s). Can use multiple `q=<keyword>`s or commas for more than one keyword
        :param str owner: search only for entries with the given owner name(s).
        :param str repo: search only for entries with the given repo name(s).
        :param str tag: search only for entries with the given release tag(s)
        :param str lang: search only for entries with the given language(s)
        :param str stage: specifies which release stage to be return of these stages: \"prod\" - return only the production releases (default); \"preprod\" - return the pre-production release if it exists instead of the production release; \"draft\" - return the draft release if it exists instead of pre-production or production release; \"latest\" -return the default branch (e.g. master) if it is a valid RC instead of the above
        :param str subject: search only for entries with the given subject(s). Must match the entire string (case insensitive)
        :param str checking_level: search only for entries with the given checking level(s). Can be 1, 2 or 3
        :param str book: search only for entries with the given book(s) (project ids)
        :param bool include_history: if true, all releases, not just the latest, are included. Default is false
        :param bool include_metadata: if false, only subject and title are searched with query terms, if true all metadata values are searched. Default is true
        :param bool show_ingredients: if true, a list of the projects in the resource and their file paths will be listed for each entry. Default is false
        :param str sort: sort repos alphanumerically by attribute. Supported values are \"subject\", \"title\", \"reponame\", \"tag\", \"released\", \"lang\", \"releases\", \"stars\", \"forks\". Default is by \"language\", \"subject\" and then \"tag\"
        :param str order: sort order, either \"asc\" (ascending) or \"desc\" (descending). Default is \"asc\", ignored if \"sort\" is not specified.
        :param int page: page number of results to return (1-based)
        :param int limit: page size of results, maximum page size is 50
        :return: CatalogSearchResultsV4
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q', 'owner', 'repo', 'tag', 'lang', 'stage', 'subject', 'checking_level', 'book', 'include_history', 'include_metadata', 'show_ingredients', 'sort', 'order', 'page', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_search" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501
        if 'owner' in params:
            query_params.append(('owner', params['owner']))  # noqa: E501
        if 'repo' in params:
            query_params.append(('repo', params['repo']))  # noqa: E501
        if 'tag' in params:
            query_params.append(('tag', params['tag']))  # noqa: E501
        if 'lang' in params:
            query_params.append(('lang', params['lang']))  # noqa: E501
        if 'stage' in params:
            query_params.append(('stage', params['stage']))  # noqa: E501
        if 'subject' in params:
            query_params.append(('subject', params['subject']))  # noqa: E501
        if 'checking_level' in params:
            query_params.append(('checkingLevel', params['checking_level']))  # noqa: E501
        if 'book' in params:
            query_params.append(('book', params['book']))  # noqa: E501
        if 'include_history' in params:
            query_params.append(('includeHistory', params['include_history']))  # noqa: E501
        if 'include_metadata' in params:
            query_params.append(('includeMetadata', params['include_metadata']))  # noqa: E501
        if 'show_ingredients' in params:
            query_params.append(('showIngredients', params['show_ingredients']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'order' in params:
            query_params.append(('order', params['order']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v4/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsV4',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def catalog_search_repo(self, owner, repo, **kwargs):  # noqa: E501
        """Catalog search by repo  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_search_repo(owner, repo, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: name of the owner (required)
        :param str repo: name of the repo (required)
        :param str q: keyword(s). Can use multiple `q=<keyword>`s or commas for more than one keyword
        :param str tag: search only for entries with the given release tag(s)
        :param str lang: search only for entries with the given language(s)
        :param str stage: specifies which release stage to be return of these stages: \"prod\" - return only the production releases (default); \"preprod\" - return the pre-production release if it exists instead of the production release; \"draft\" - return the draft release if it exists instead of pre-production or production release; \"latest\" -return the default branch (e.g. master) if it is a valid RC instead of the above
        :param str subject: search only for entries with the given subject(s). Must match the entire string (case insensitive)
        :param str checking_level: search only for entries with the given checking level(s). Can be 1, 2 or 3
        :param str book: search only for entries with the given book(s) (project ids)
        :param bool include_history: if true, all releases, not just the latest, are included. Default is false
        :param bool include_metadata: if false, only subject and title are searched with query terms, if true all metadata values are searched. Default is true
        :param bool show_ingredients: if true, a list of the projects in the resource and their file paths will be listed for each entry. Default is false
        :param str sort: sort repos alphanumerically by attribute. Supported values are \"subject\", \"title\", \"reponame\", \"tag\", \"released\", \"lang\", \"releases\", \"stars\", \"forks\". Default is by \"language\", \"subject\" and then \"tag\"
        :param str order: sort order, either \"asc\" (ascending) or \"desc\" (descending). Default is \"asc\", ignored if \"sort\" is not specified.
        :param int page: page number of results to return (1-based)
        :param int limit: page size of results, maximum page size is 50
        :return: CatalogSearchResultsV4
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.catalog_search_repo_with_http_info(owner, repo, **kwargs)  # noqa: E501
        else:
            (data) = self.catalog_search_repo_with_http_info(owner, repo, **kwargs)  # noqa: E501
            return data

    def catalog_search_repo_with_http_info(self, owner, repo, **kwargs):  # noqa: E501
        """Catalog search by repo  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.catalog_search_repo_with_http_info(owner, repo, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner: name of the owner (required)
        :param str repo: name of the repo (required)
        :param str q: keyword(s). Can use multiple `q=<keyword>`s or commas for more than one keyword
        :param str tag: search only for entries with the given release tag(s)
        :param str lang: search only for entries with the given language(s)
        :param str stage: specifies which release stage to be return of these stages: \"prod\" - return only the production releases (default); \"preprod\" - return the pre-production release if it exists instead of the production release; \"draft\" - return the draft release if it exists instead of pre-production or production release; \"latest\" -return the default branch (e.g. master) if it is a valid RC instead of the above
        :param str subject: search only for entries with the given subject(s). Must match the entire string (case insensitive)
        :param str checking_level: search only for entries with the given checking level(s). Can be 1, 2 or 3
        :param str book: search only for entries with the given book(s) (project ids)
        :param bool include_history: if true, all releases, not just the latest, are included. Default is false
        :param bool include_metadata: if false, only subject and title are searched with query terms, if true all metadata values are searched. Default is true
        :param bool show_ingredients: if true, a list of the projects in the resource and their file paths will be listed for each entry. Default is false
        :param str sort: sort repos alphanumerically by attribute. Supported values are \"subject\", \"title\", \"reponame\", \"tag\", \"released\", \"lang\", \"releases\", \"stars\", \"forks\". Default is by \"language\", \"subject\" and then \"tag\"
        :param str order: sort order, either \"asc\" (ascending) or \"desc\" (descending). Default is \"asc\", ignored if \"sort\" is not specified.
        :param int page: page number of results to return (1-based)
        :param int limit: page size of results, maximum page size is 50
        :return: CatalogSearchResultsV4
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner', 'repo', 'q', 'tag', 'lang', 'stage', 'subject', 'checking_level', 'book', 'include_history', 'include_metadata', 'show_ingredients', 'sort', 'order', 'page', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method catalog_search_repo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'owner' is set
        if self.api_client.client_side_validation and ('owner' not in params or
                                                       params['owner'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `owner` when calling `catalog_search_repo`")  # noqa: E501
        # verify the required parameter 'repo' is set
        if self.api_client.client_side_validation and ('repo' not in params or
                                                       params['repo'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `repo` when calling `catalog_search_repo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'owner' in params:
            path_params['owner'] = params['owner']  # noqa: E501
        if 'repo' in params:
            path_params['repo'] = params['repo']  # noqa: E501

        query_params = []
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501
        if 'tag' in params:
            query_params.append(('tag', params['tag']))  # noqa: E501
        if 'lang' in params:
            query_params.append(('lang', params['lang']))  # noqa: E501
        if 'stage' in params:
            query_params.append(('stage', params['stage']))  # noqa: E501
        if 'subject' in params:
            query_params.append(('subject', params['subject']))  # noqa: E501
        if 'checking_level' in params:
            query_params.append(('checkingLevel', params['checking_level']))  # noqa: E501
        if 'book' in params:
            query_params.append(('book', params['book']))  # noqa: E501
        if 'include_history' in params:
            query_params.append(('includeHistory', params['include_history']))  # noqa: E501
        if 'include_metadata' in params:
            query_params.append(('includeMetadata', params['include_metadata']))  # noqa: E501
        if 'show_ingredients' in params:
            query_params.append(('showIngredients', params['show_ingredients']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'order' in params:
            query_params.append(('order', params['order']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AccessToken', 'AuthorizationHeaderToken', 'BasicAuth', 'SudoHeader', 'SudoParam', 'TOTPHeader', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/v4/search/{owner}/{repo}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CatalogSearchResultsV4',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import dcs_catalog_client
from dcs_catalog_client.models.catalog_v3 import CatalogV3  # noqa: E501
from dcs_catalog_client.rest import ApiException


class TestCatalogV3(unittest.TestCase):
    """CatalogV3 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCatalogV3(self):
        """Test CatalogV3"""
        # FIXME: construct object with mandatory attributes with example values
        # model = dcs_catalog_client.models.catalog_v3.CatalogV3()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class CatalogStage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'branch_or_tag_name': 'str',
        'contents_url': 'str',
        'git_trees_url': 'str',
        'release_url': 'str',
        'released': 'datetime',
        'tarball_url': 'str',
        'zipball_url': 'str'
    }

    attribute_map = {
        'branch_or_tag_name': 'branch_or_tag_name',
        'contents_url': 'contents_url',
        'git_trees_url': 'git_trees_url',
        'release_url': 'release_url',
        'released': 'released',
        'tarball_url': 'tarball_url',
        'zipball_url': 'zipball_url'
    }

    def __init__(self, branch_or_tag_name=None, contents_url=None, git_trees_url=None, release_url=None, released=None, tarball_url=None, zipball_url=None, _configuration=None):  # noqa: E501
        """CatalogStage - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._branch_or_tag_name = None
        self._contents_url = None
        self._git_trees_url = None
        self._release_url = None
        self._released = None
        self._tarball_url = None
        self._zipball_url = None
        self.discriminator = None

        if branch_or_tag_name is not None:
            self.branch_or_tag_name = branch_or_tag_name
        if contents_url is not None:
            self.contents_url = contents_url
        if git_trees_url is not None:
            self.git_trees_url = git_trees_url
        if release_url is not None:
            self.release_url = release_url
        if released is not None:
            self.released = released
        if tarball_url is not None:
            self.tarball_url = tarball_url
        if zipball_url is not None:
            self.zipball_url = zipball_url

    @property
    def branch_or_tag_name(self):
        """Gets the branch_or_tag_name of this CatalogStage.  # noqa: E501


        :return: The branch_or_tag_name of this CatalogStage.  # noqa: E501
        :rtype: str
        """
        return self._branch_or_tag_name

    @branch_or_tag_name.setter
    def branch_or_tag_name(self, branch_or_tag_name):
        """Sets the branch_or_tag_name of this CatalogStage.


        :param branch_or_tag_name: The branch_or_tag_name of this CatalogStage.  # noqa: E501
        :type: str
        """

        self._branch_or_tag_name = branch_or_tag_name

    @property
    def contents_url(self):
        """Gets the contents_url of this CatalogStage.  # noqa: E501


        :return: The contents_url of this CatalogStage.  # noqa: E501
        :rtype: str
        """
        return self._contents_url

    @contents_url.setter
    def contents_url(self, contents_url):
        """Sets the contents_url of this CatalogStage.


        :param contents_url: The contents_url of this CatalogStage.  # noqa: E501
        :type: str
        """

        self._contents_url = contents_url

    @property
    def git_trees_url(self):
        """Gets the git_trees_url of this CatalogStage.  # noqa: E501


        :return: The git_trees_url of this CatalogStage.  # noqa: E501
        :rtype: str
        """
        return self._git_trees_url

    @git_trees_url.setter
    def git_trees_url(self, git_trees_url):
        """Sets the git_trees_url of this CatalogStage.


        :param git_trees_url: The git_trees_url of this CatalogStage.  # noqa: E501
        :type: str
        """

        self._git_trees_url = git_trees_url

    @property
    def release_url(self):
        """Gets the release_url of this CatalogStage.  # noqa: E501


        :return: The release_url of this CatalogStage.  # noqa: E501
        :rtype: str
        """
        return self._release_url

    @release_url.setter
    def release_url(self, release_url):
        """Sets the release_url of this CatalogStage.


        :param release_url: The release_url of this CatalogStage.  # noqa: E501
        :type: str
        """

        self._release_url = release_url

    @property
    def released(self):
        """Gets the released of this CatalogStage.  # noqa: E501


        :return: The released of this CatalogStage.  # noqa: E501
        :rtype: datetime
        """
        return self._released

    @released.setter
    def released(self, released):
        """Sets the released of this CatalogStage.


        :param released: The released of this CatalogStage.  # noqa: E501
        :type: datetime
        """

        self._released = released

    @property
    def tarball_url(self):
        """Gets the tarball_url of this CatalogStage.  # noqa: E501


        :return: The tarball_url of this CatalogStage.  # noqa: E501
        :rtype: str
        """
        return self._tarball_url

    @tarball_url.setter
    def tarball_url(self, tarball_url):
        """Sets the tarball_url of this CatalogStage.


        :param tarball_url: The tarball_url of this CatalogStage.  # noqa: E501
        :type: str
        """

        self._tarball_url = tarball_url

    @property
    def zipball_url(self):
        """Gets the zipball_url of this CatalogStage.  # noqa: E501


        :return: The zipball_url of this CatalogStage.  # noqa: E501
        :rtype: str
        """
        return self._zipball_url

    @zipball_url.setter
    def zipball_url(self, zipball_url):
        """Sets the zipball_url of this CatalogStage.


        :param zipball_url: The zipball_url of this CatalogStage.  # noqa: E501
        :type: str
        """

        self._zipball_url = zipball_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CatalogStage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogStage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogStage):
            return True

        return self.to_dict() != other.to_dict()
